@@ -10,7 +10,8 @@
 #ifndef ATOM_H
 #define ATOM_H
 
-//#include "libghemicalconfig2.h"
+#include "libghemicaldefine.h"
+#include "libghemicalconfig2.h"
 
 class element;
 
@@ -22,7 +23,6 @@ class atom;
 class bond;	// bond.h
 class model;	// model.h
 
-#include "libdefine.h"
 #include "typedef.h"
 
 #include <list>
@@ -103,26 +103,20 @@ class crec
 
 /*################################################################################################*/
 
-#define ATOMFLAG_SELECTED		(1 << 0)	// 0x00000001
-#define ATOMFLAG_REQUEST_VISIBLE	(1 << 1)	// 0x00000002
-#define ATOMFLAG_REQUEST_QUANTUM_ATOM	(1 << 2)	// 0x00000002
-#define ATOMFLAG_REQUEST_UNITED_ATOM	(1 << 3)	// 0x00000004
-#define ATOMFLAG_REQUEST_SF_ATOM	(1 << 4)	// 0x00000004
+#define ATOMFLAG_USER_SELECTED		(1 << 0)	// 0x00000001
+#define ATOMFLAG_USER_HIDDEN		(1 << 1)	// 0x00000002
+#define ATOMFLAG_USER_LOCKED		(1 << 2)	// 0x00000004 ; the USER_LOCKED flag means:
+// 1) DoSHAKE() should not move it 2) in MD acc/vel always 0.0 and is not included when calculating Ekin/T.
+// THIS IS STILL AN INCOMPLETE IMPLEMENTATION!!! be careful with this and test before any serious use...
 
-#define ATOMFLAG_IS_SOLVENT_ATOM	(1 << 8)	// 0x00000008	16 ja yli???
-#define ATOMFLAG_MEASURE_ND_RDF		(1 << 9)	// 0x00000008	16 ja yli???
-#define ATOMFLAG_COUNT_IN_RDF		(1 << 10)	// 0x00000008	16 ja yli???
+#define ATOMFLAG_IS_SOLVENT_ATOM	(1 << 8)	// 0x00000008
+#define ATOMFLAG_MEASURE_ND_RDF		(1 << 9)
+#define ATOMFLAG_COUNT_IN_RDF		(1 << 10)
 
-#define ATOMFLAG_IS_QM_ATOM		(1 << 11)	// 0x00000008	16 ja yli???
-#define ATOMFLAG_IS_MM_ATOM		(1 << 12)	// 0x00000008	16 ja yli???
-#define ATOMFLAG_IS_SF_ATOM		(1 << 13)	// 0x00000008	16 ja yli???
-#define ATOMFLAG_IS_HIDDEN		(1 << 14)	// 0x00000008	16 ja yli???
-
-#define ATOMFLAG_IS_LOCKED		(1 << 15)	// 0x00000008	16 ja yli???
-// the LOCKED flag means : 1) DoSHAKE() should not move it 2) in MD acc/vel always 0.0, and is not included when calculating Ekin/T.
-// THIS IS STILL AN INCOMPLETE IMPLEMENTATION!!! the flag is IGNORED for example in geometry optimization ; see the sf-model...
-
-// - protected??? not needed?
+#define ATOMFLAG_IS_QM_ATOM		(1 << 11)
+#define ATOMFLAG_IS_MM_ATOM		(1 << 12)
+#define ATOMFLAG_IS_SF_ATOM		(1 << 13)
+#define ATOMFLAG_IS_HIDDEN		(1 << 14)
 
 /// An atom class.
 /** Will store all data about an atom, including type, coordinates, and a connectivity 
@@ -186,6 +180,12 @@ mol/chn id's are unique, but res/atm numbers are repeated in different chains an
 	const fGL * GetCRD(i32u);
 	void SetCRD(i32s, fGL, fGL, fGL);
 	
+	bool GetSelected(void) const;
+	void SetSelected(bool);
+	
+	bool GetLocked(void) const;
+	void SetLocked(bool);
+	
 	bool operator<(const atom &) const;	///< Using id-numbers.
 	bool operator==(const atom &) const;	///< Using pointers.
 };
