@@ -10,6 +10,7 @@
 #ifndef BOND_H
 #define BOND_H
 
+#include "libghemicaldefine.h"
 //#include "libghemicalconfig2.h"
 
 class bondtype;
@@ -20,7 +21,6 @@ class bond;
 
 class atom;	// atom.h
 
-#include "libdefine.h"
 #include "typedef.h"
 
 #include <list>
