@@ -20,10 +20,10 @@ struct mm_default_bt4;		// out-of-plane
 struct mm_default_nbt1;		// nonbonded terms
 
 class eng1_mm_default_bt;		// bonded part
-class eng1_mm_default_nbt_mbp;		// nonbonded part; (optional) modified boundary potential
+class eng1_mm_default_nbt_bp;		// nonbonded part; (optional) boundary potential
 class eng1_mm_default_nbt_mim;		// nonbonded part; minimum image model
 
-class eng1_mm_default_mbp;
+class eng1_mm_default_bp;
 class eng1_mm_default_mim;
 
 /*################################################################################################*/
@@ -184,13 +184,13 @@ class eng1_mm_default_bt : virtual public eng1_mm
 
 /*################################################################################################*/
 
-/// molecular mechanics; nonbonded part, modified boundary potential.
+/// molecular mechanics; nonbonded part, boundary potential.
 
 // TODO : how to measure the radial density of the solvent sphere??? what about pressure???
 // TODO : how to measure the radial density of the solvent sphere??? what about pressure???
 // TODO : how to measure the radial density of the solvent sphere??? what about pressure???
 
-class eng1_mm_default_nbt_mbp : virtual public eng1_mm, virtual public engine_mbp
+class eng1_mm_default_nbt_bp : virtual public eng1_mm, virtual public engine_bp
 {
 	protected:
 	
@@ -198,8 +198,8 @@ class eng1_mm_default_nbt_mbp : virtual public eng1_mm, virtual public engine_mb
 	
 	public:
 	
-	eng1_mm_default_nbt_mbp(setup *, i32u);
-	virtual ~eng1_mm_default_nbt_mbp(void);
+	eng1_mm_default_nbt_bp(setup *, i32u);
+	virtual ~eng1_mm_default_nbt_bp(void);
 	
 	protected:
 	
@@ -248,12 +248,12 @@ class eng1_mm_default_nbt_mim : virtual public eng1_mm, public engine_pbc
 
 /*################################################################################################*/
 
-class eng1_mm_default_mbp : public eng1_mm_default_bt, public eng1_mm_default_nbt_mbp
+class eng1_mm_default_bp : public eng1_mm_default_bt, public eng1_mm_default_nbt_bp
 {
 	public:
 	
-	eng1_mm_default_mbp(setup *, i32u);
-	~eng1_mm_default_mbp(void);
+	eng1_mm_default_bp(setup *, i32u);
+	~eng1_mm_default_bp(void);
 };
 
 class eng1_mm_default_mim : public eng1_mm_default_bt, public eng1_mm_default_nbt_mim
