@@ -15,8 +15,12 @@ geomopt::geomopt(engine * p1, i32s p2, f64 p3, f64 p4) : conjugate_gradient(p2,
 {
 	eng = p1;
 	
+	atom ** glob_atmtab = eng->GetSetup()->GetAtoms();
+	
 	for (i32s n1 = 0;n1 < eng->GetAtomCount();n1++)
 	{
+		if (glob_atmtab[n1]->flags & ATOMFLAG_USER_LOCKED) continue;
+		
 		for (i32s n2 = 0;n2 < 3;n2++)
 		{
 			AddVar(& eng->crd[n1 * 3 + n2], & eng->d1[n1 * 3 + n2]);
