@@ -10,6 +10,7 @@
 #ifndef MODEL_H
 #define MODEL_H
 
+#include "libghemicaldefine.h"
 //#include "libghemicalconfig2.h"
 
 class model;
@@ -34,8 +35,15 @@ class setup;			// engine.h
 class engine;			// engine.h
 
 class geomopt_param;		// geomopt.h
+
+class moldyn;			// moldyn.h
 class moldyn_param;		// moldyn.h
 
+#include "atom.h"
+#include "bond.h"
+
+#include "constraint.h"
+
 #include "seqbuild.h"
 
 #include <list>
@@ -63,6 +71,8 @@ class model
 	list<atom> atom_list;
 	list<bond> bond_list;
 	
+	list<constraint_dst> const_D_list;
+	
 	vector<crd_set *> cs_vector;	///< This determines how many crd_sets there are in the model.
 	i32u crd_table_size_glob;	///< This determines how big the crd_table arrays are; always >= than above!!!
 	
@@ -74,15 +84,20 @@ class model
 	i32s qm_current_orbital;
 	
 	bool use_boundary_potential;
-	f64 boundary_potential_radius1;		// for solute...
-	f64 boundary_potential_radius2;		// for solvent...
+	f64 saved_boundary_potential_rad_solute;
+	f64 saved_boundary_potential_rad_solvent;
 	
 	bool use_periodic_boundary_conditions;
-	f64 periodic_box_HALFdim[3];
+	f64 saved_periodic_box_HALFdim[3];
 	
 	i32s nmol;
 	vector<chn_info> * ref_civ;	// vector<chn_info *> ?!?!?!
 	
+	ifstream * trajfile;		// trajectory files...
+	i32s traj_num_atoms;		// trajectory files...
+	i32s total_traj_frames;		// trajectory files...
+	i32s current_traj_frame;	// trajectory files...
+	
 	vector<const char *> ecomp_grp_name_usr;
 	
 //	int ecomp_ngrps;
@@ -115,36 +130,6 @@ class model
 	static sequencebuilder amino_builder;
 	static sequencebuilder nucleic_builder;
 	
-	friend class sequencebuilder;
-
-	friend class engine;
-	friend class engine_mbp;
-	friend class engine_pbc;
-
-	friend class setup1_qm;
-	friend class eng1_qm_mopac;
-	
-	friend class setup1_mm;
-	friend class eng1_mm_pbc;
-	
-	friend class eng1_mm_tripos52_nbt_mbp;
-	friend class eng1_mm_tripos52_nbt_mim;
-	
-	friend class eng1_mm_default_nbt_mbp;
-	friend class eng1_mm_default_nbt_mim;
-	friend class default_tables;
-	
-	friend class setup1_sf;
-	
-	friend class color_mode_element;	// this is for ghemical!!!
-	friend class color_mode_secstruct;	// this is for ghemical!!!
-	friend class color_mode_hydphob;	// this is for ghemical!!!
-	
-	friend class setup_druid;	// this is for ghemical!!! // needs access to current_setup...	// for BBB
-	friend class setup_dialog;	// this is for ghemical!!! // needs access to current_setup...	// for HEAD
-friend class ribbon;		// this is for ghemical!!!
-friend class ssc_view;		// this is for ghemical!!!
-	
 	friend void CopyCRD(model *, engine *, i32u);
 	friend void CopyCRD(engine *, model *, i32u);
 	
@@ -154,6 +139,29 @@ friend class ssc_view;		// this is for ghemical!!!
 	friend void DefineSecondaryStructure(model *);
 	friend f64 HBondEnergy(model *, i32s *, i32s *);
 	
+	friend class sequencebuilder;
+
+	friend class engine;
+	friend class engine_bp;
+	friend class engine_pbc;
+
+	friend class setup1_qm;
+	friend class eng1_qm_mopac;
+	
+	friend class setup1_mm;
+	friend class eng1_mm_pbc;
+	
+	friend class eng1_mm_tripos52_nbt_bp;
+	friend class eng1_mm_tripos52_nbt_mim;
+	
+	friend class eng1_mm_default_nbt_bp;
+	friend class eng1_mm_default_nbt_mim;
+	friend class default_tables;
+	
+	friend class setup1_sf;
+	
+	friend class moldyn;
+	
 	public:
 	
 	model(void);
@@ -168,6 +176,7 @@ friend class ssc_view;		// this is for ghemical!!!
 	virtual void ErrorMessage(const char *);
 	
 	setup * GetCurrentSetup(void);
+	void ReplaceCurrentSetup(setup *);
 	
 	resonance_structures * GetRS(void);
 	
@@ -205,6 +214,8 @@ friend class ssc_view;		// this is for ghemical!!!
 	void SwapCRDSets(i32u, i32u);
 	
 	void CenterCRDSet(i32u, bool);
+	void OrientCRDSet(i32u, bool, fGL *);
+	
 	void ReserveCRDSets(i32u);
 
 	virtual void DiscardCurrEng(void);
@@ -222,7 +233,10 @@ friend class ssc_view;		// this is for ghemical!!!
 	
 	virtual void AddBond(bond &);		///< This will add neighbor infos for both atoms and add the new bond into the bond list.
 	virtual void RemoveBond(iter_bl);	///< This will remove infos from the atoms and erase bond from the bond list.
-
+	
+	virtual void AddConstraint(constraint_dst &);
+	virtual void RemoveConstraint(iter_CDl);
+	
 	void SystemWasModified(void);	///< This should be called ALWAYS if ANY modification is done to the system. Automatically called by Add/Remove/Atom/Bond. GUI should change if change in element etc...
 	
 	void ClearModel(void);		///< This will remove all atoms and bonds.
@@ -233,21 +247,27 @@ friend class ssc_view;		// this is for ghemical!!!
 	
 	iter_al GetAtomsBegin(void) { return atom_list.begin(); }	//const;
 	iter_al GetAtomsEnd(void) { return atom_list.end(); }		//const;
+	atom & GetLastAtom(void) { return atom_list.back(); }
+	i32s GetAtomCount(void) { return atom_list.size(); }	///< This will return atom_list.size().
 	
 	iter_bl GetBondsBegin(void) { return bond_list.begin(); }	//const;
 	iter_bl GetBondsEnd(void) { return bond_list.end(); }		//const;
-	
-	atom & GetLastAtom(void) { return atom_list.back(); }
 	bond & GetLastBond(void) { return bond_list.back(); }
+	i32s GetBondCount(void) { return bond_list.size(); }	///< This will return bond_list.size().
+	
+	iter_CDl GetConstD_begin(void) { return const_D_list.begin(); }		//const;
+	iter_CDl GetConstD_end(void) { return const_D_list.end(); }		//const;
+	constraint_dst & GetLastConstD(void) { return const_D_list.back(); }
+	i32s GetConstD_count(void) { return const_D_list.size(); }	///< This will return const_D_list.size().
 	
 	// methods for ???
 	// ^^^^^^^^^^^^^^^
 	
 	i32s GetQMTotalCharge(void) { return qm_total_charge; }
-	i32s GetQMCurrentOrbital(void) { return qm_current_orbital; }
+	void SetQMTotalCharge(i32s tc) { qm_total_charge = tc; }
 	
-	i32s GetAtomCount(void) { return atom_list.size(); }	///< This will return atom_list.size().
-	i32s GetBondCount(void) { return bond_list.size(); }	///< This will return bond_list.size().
+	i32s GetQMCurrentOrbital(void) { return qm_current_orbital; }
+	void SetQMCurrentOrbital(i32s orb) { qm_current_orbital = orb; }
 	
 	i32s GetMoleculeCount(void) { return nmol; }			///< This will return nmol (see UpdateGroups() for more info).
 
@@ -258,6 +278,7 @@ friend class ssc_view;		// this is for ghemical!!!
 	bool IsGroupsSorted(void) { return is_groups_sorted; }
 	
 	iter_al FindAtomByIndex(i32s);
+	iter_CDl FindAtomConstraint(atom &);
 	
 	void GetRange(i32s, i32s, iter_al *);	///< This is just a default version of GetRange() using the full range of atom list iterators...
 	
@@ -294,6 +315,8 @@ Finally it will call model::SortGroups() so that chains and residues in the atom
 sequentially in contiguous blocks. */
 	virtual void UpdateChains(void);
 	
+	vector<chn_info> * GetCI(void) { return ref_civ; }
+	
 	private:
 	
 /** This will set molecule numbers quickly using a recursive search algorithm. 
@@ -361,6 +384,26 @@ example to evaluate quality of the data or to match the data with records in oth
 	i32s readpdb_ReadData_sub1(vector<readpdb_data_atom> &, i32s *, const char *, bool);
 	void readpdb_ReadData_sub2(vector<readpdb_data_atom> &, i32s *, const char *, const char *, char);
 	
+// methods related to MD trajectories...
+// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	void OpenTrajectory(const char *);
+	void ReadTrajectoryFrame(void);
+	void CloseTrajectory(void);
+	
+	i32s GetTotalFrames(void);
+	ifstream * GetTrajectoryFile(void);
+	
+	i32s GetCurrentFrame(void);
+	void SetCurrentFrame(i32s);
+	
+	void WriteTrajectoryHeader(ofstream &, int);
+	void WriteTrajectoryFrame(ofstream &, moldyn *);
+	
+	void EvaluateBFact(void);
+	void EvaluateDiffConst(double);
+	
+// this is not ready yet...
+// ^^^^^^^^^^^^^^^^^^^^^^^^
 	void ecomp_AddGroupU(const char *);
 	bool ecomp_DeleteGroupU(int);
 	
