@@ -9,13 +9,13 @@
 
 #include "seqbuild.h"
 
-#include "libdefine.h"
+#include "v3d.h"
 
 #include <string.h>
 
 #include <iomanip>
 #include <iostream>
-#include <strstream>
+#include <sstream>
 using namespace std;
 
 /*################################################################################################*/
