@@ -10,6 +10,7 @@
 #ifndef SEQBUILD_H
 #define SEQBUILD_H
 
+#include "libghemicaldefine.h"
 //#include "libghemicalconfig2.h"
 
 class chn_info;
@@ -30,8 +31,6 @@ struct sb_tdata;
 #include "model.h"
 #include "typerule.h"
 
-#include "v3d.h"
-
 typedef vector<atom *> atmr_vector;
 
 /*################################################################################################*/
@@ -216,8 +215,8 @@ class sb_data_res
 
 	friend class sequencebuilder;
 	
-	friend class model;			// old???
-	friend class setup1_sf;			// new!!!
+	friend class model;		// old???
+	friend class setup1_sf;		// new!!!
 	
 	public:
 	
