@@ -9,13 +9,13 @@
 
 #include "utility.h"
 
-#include "libdefine.h"
+#include "v3d.h"
 
 #include <string.h>
 
 #include <iomanip>
 #include <iostream>
-#include <strstream>
+#include <sstream>
 using namespace std;
 
 /*################################################################################################*/
@@ -248,18 +248,6 @@ void superimpose::Transform(void)
 
 /*################################################################################################*/
 
-void TransformVector(v3d<fGL> & p1, const fGL * p2)
-{
-	i32s n1; i32s n2; fGL pv[4]; pv[3] = 1.0;
-	for (n1 = 0;n1 < 3;n1++) pv[n1] = p1.data[n1];
-	
-	fGL rv[4] = { 0.0, 0.0, 0.0, 0.0 };
-	for (n1 = 0;n1 < 4;n1++) for (n2 = 0;n2 < 4;n2++) rv[n1] += pv[n2] * p2[n2 * 4 + n1];
-	for (n1 = 0;n1 < 3;n1++) p1.data[n1] = rv[n1] / rv[3];
-}
-
-/*################################################################################################*/
-
 #define HBOND_TRESHOLD -1.0	// h-bond energy treshold kcal/mol (K&S used -0.5 kcal/mol?)
 
 #define HELIX_CHECK (M_PI * 45.0 / 180.0)	// geometry tresholds for helix torsions...
@@ -466,6 +454,8 @@ void DefineSecondaryStructure(model * mdl)
 // for simplified residues, no changes are needed here?!?!?!
 // in sf cases 0.0 is just returned since no O/N atoms are found.
 
+// res1 = H-bond acceptor ; res2 = H-bond donor.
+
 f64 HBondEnergy(model * mdl, i32s * res1, i32s * res2)
 {
 	vector<chn_info> & ci_vector = (* mdl->ref_civ);
