@@ -10,6 +10,7 @@
 #ifndef UTILITY_H
 #define UTILITY_H
 
+#include "libghemicaldefine.h"
 //#include "libghemicalconfig2.h"
 
 class superimpose;
@@ -23,8 +24,6 @@ class superimpose;
 
 #include "conjgrad.h"
 
-#include "v3d.h"
-
 /*################################################################################################*/
 
 /// This class can be used to superimpose coordinate sets.
@@ -87,17 +86,6 @@ template<class TYPE1> class singleton_cleaner
 
 /*################################################################################################*/
 
-/**	This function can be used to modify a 3D-vector object using a 4x4 transformation 
-	matrix. Will first make a [1*4]x[4x4]-type matrix product and after that bring the 
-	result back to 3D.
-	
-	For more complete documentation search for "##homogeneous coordinates"...
-*/
-
-void TransformVector(v3d<fGL> &, const fGL *);
-
-/*################################################################################################*/
-
 #define HBOND_TRESHOLD -1.0			// h-bond energy treshold kcal/mol (K&S used -0.5 kcal/mol???)
 
 #define HELIX_CHECK (M_PI * 45.0 / 180.0)	// geometry tresholds for helix torsions...
